'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

/**
 *
 * 根据key获取url中的参数，默认从search取,也支持从整个url中获取
 * @category  url
 * @param {string} [url=window.location.href]
 * @param {string} key
 * @returns {string}
 * @author hzxiongxu
 * @date 20210520
 *
 */
function getUrlParams(key, url) {
    if (url === void 0) { url = window.location.href; }
    var reg = new RegExp("(^|&|\\?|#)" + key + "=([^&]*)(&|$|\\?|#)", 'i');
    var r = url.substr(1).match(reg);
    if (r != null) {
        return decodeURI(r[2]);
    }
    return '';
}
/**
 *
 * 获取url所有参数
 * @category  url
 * @param {string} [url=window.location.href]
 * @return {*}  {Record<string, any>}
 * @author hzxiongxu
 * @date 20210520
 */
function getAllUrlParams(url) {
    if (url === void 0) { url = window.location.href; }
    var query = [];
    var params = {};
    if (url.indexOf('?') === -1) {
        query = url.split('&');
    }
    else {
        query = url.split('?')[1].split('&');
    }
    query.forEach(function (item) {
        var q = item.split('=');
        if (q.length === 2) {
            params[q[0]] = q[1];
        }
    });
    return params;
}

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

/**
 *
 * 金额转换，支持小数点，单位，千分位配置
 * @category  format
 * @param {number} m 输入金额
 * @param {Rule} [rule] interface接口，支持是否使用千分位，
 * @returns {(string|number)}
 * @author hzxiongxu
 * @date 20210520
 *
 */
function moneyFormat(m, rule) {
    // 默认2位小数加上千分位
    var p = {
        decimalPlaces: 2,
        useThousands: true,
        unit: '',
        symbol: ''
    };
    var params = __assign(__assign({}, p), rule);
    var result = '0.00';
    if (m !== null && m !== undefined) {
        var fixedNum = Number(m).toFixed(params.decimalPlaces);
        result = params.useThousands ? fixedNum.replace(/\B(?=(\d{3})+\b)/g, ',') : fixedNum;
    }
    return "" + params.symbol + result + params.unit;
}
/**
 * 格式化卡号格式：仅数字，4位一空格 （1111 2222 3333）
 * @format  format
 * @param {string} value
 * @param {number} limit
 * @author hzxiongxu
 * @date 20210520
 */
function cardNoFormat(value, limit) {
    if (limit === void 0) { limit = 25; }
    if (value) {
        var formatValue = value.replace(/[^0-9]/g, '');
        if (limit) {
            formatValue = formatValue.length > limit ? formatValue.slice(0, limit) : formatValue;
        }
        return formatValue.replace(/(\d{4})(?=.)/g, '$1 ');
    }
    return value;
}
/**
 *
 * 格式化手机号格式：仅数字，344分隔 （133 2222 3333）
 * @category format
 * @param {string} value
 * @returns {string}
 * @author hzxiongxu
 * @date 20210520
 *
 */
function mobileNoFormat(value) {
    if (value) {
        var formatValue = value.replace(/[^0-9]/g, '');
        return formatValue.replace(/(\d{3})(?!$)/, '$1 ').replace(/(\d{4})(?!$)/, '$1 ');
    }
    return value;
}

/**
 *
 * 浮点数相加
 * @category  math
 * @param {number} arg1
 * @param {number} arg2
 * @return {*}  {number}
 * @author hzxiongxu
 * @date 20210520
 */
function floatAdd(arg1, arg2) {
    var r1;
    var r2;
    try {
        r1 = arg1.toString().split('.')[1].length;
    }
    catch (e) {
        r1 = 0;
    }
    try {
        r2 = arg2.toString().split('.')[1].length;
    }
    catch (e) {
        r2 = 0;
    }
    var m = Math.pow(10, Math.max(r1, r2));
    return Math.round(arg1 * m + arg2 * m) / m;
}
/**
 *
 * 浮点数减法
 * @category  math
 * @param {number} arg1
 * @param {number} arg2
 * @return {*}  {number}
 * @author hzxiongxu
 * @date 20210520
 */
function floatSub(arg1, arg2) {
    var r1;
    var r2;
    try {
        r1 = arg1.toString().split('.')[1].length;
    }
    catch (e) {
        r1 = 0;
    }
    try {
        r2 = arg2.toString().split('.')[1].length;
    }
    catch (e) {
        r2 = 0;
    }
    var m = Math.pow(10, Math.max(r1, r2));
    // 动态控制精度长度
    var n = r1 >= r2 ? r1 : r2;
    // 添加了结果为整数时精度长度不准确的问题
    var r = ((arg1 * m - arg2 * m) / m).toFixed(n);
    if (r.split('.')[1]) {
        if (Number(r.split('.')[1]) === 0) {
            return +r.split('.')[0];
        }
    }
    return +((arg1 * m - arg2 * m) / m).toFixed(n);
}

var ua = window.navigator.userAgent;
var Chrome = /CriOS/i.test(ua) || /Chrome/i.test(ua);
var IOS = /(iPhone|iPad|iPod|iOS)/gi.test(ua);
var WxMiniProgram = /miniprogram/i.test(ua) || window.__wxjs_environment === 'miniprogram';
/**
 * 通过UA判断设备信息,参数请参考DeviceDto接口
 * @type {*}
 * @author hzxiongxu
 * @date 20210524
 *  */
var device = {
    Mobile: /(iPhone|iPad|iPod|iOS|Android|adr|Windows Phone|SymbianOS)/gi.test(navigator.userAgent),
    IOS: IOS,
    Android: /android|adr/gi.test(ua),
    WX: /MicroMessenger/i.test(ua) && !WxMiniProgram,
    Epay: /epay163/gi.test(ua),
    EpayApp: /epay163App/gi.test(ua),
    EpaySDK: /epay163SDK/gi.test(ua),
    Safari: IOS && /Safari/i.test(navigator.userAgent) && !Chrome,
    Chrome: Chrome,
    WxMiniProgram: WxMiniProgram,
    Cbg: /app_cbg/i.test(ua)
};

exports.cardNoFormat = cardNoFormat;
exports.device = device;
exports.floatAdd = floatAdd;
exports.floatSub = floatSub;
exports.getAllUrlParams = getAllUrlParams;
exports.getUrlParams = getUrlParams;
exports.mobileNoFormat = mobileNoFormat;
exports.moneyFormat = moneyFormat;
